function[next_matrix, next_bg] = maximization(seqs, expectations, pcounts)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% This method maximizes both foreground and background models
%% with respect to all the sequences.  The "real" work here 
%% goes on inside "expected_counts()".
%% 'pcounts' is an array of pseudocounts.
%% 'expectations' is the weighting-array, which needs to be in *non-log* scale.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

window = size(pcounts, 2);
letters = size(pcounts, 1);

base_counts = pcounts;
base_bg_counts = ones(1, letters) * (1.0 / letters);

for i =1:size(seqs, 1)
	[base_counts, base_bg_counts] = expected_counts(seqs(i, :), expectations(i, :), base_counts, base_bg_counts, window);
end

%% Both distributions need to be normalized before returning.
next_matrix = normalize_matrix(base_counts);
next_bg = base_bg_counts ./ sum(base_bg_counts);


